/**
 * La classe d'une tâche <em>cronée</em>.
 *
 * @class Cron
 */
export const Cron: {
    new (cronex: string | string[], func: Function, active?: boolean): {
        /**
         * La liste des expressions <em>cron</em> indiquant les horaires d'exécution
         * de la tâche.
         *
         * @type {CronExp[]}
         * @private
         */
        _cronexes: {
            /**
             * Les valeurs possibles pour les minutes.
             *
             * @type {Field}
             * @private
             */
            _minutes: {
                /**
                 * La liste des valeurs autorisées pour le champ (en enlevant les doublons
                 * et en triant).
                 *
                 * @type {number[]}
                 * @private
                 */
                _values: number[];
                /**
                 * <code>true</code> si le champ était différent de <code>"*"</code> ; sinon
                 * <code>false</code>.
                 *
                 * @type {boolean}
                 * @private
                 */
                _restricted: boolean;
                /**
                 * Retourne la marque indiquant si le champ était différent de
                 * <code>"*"</code>.
                 *
                 * @returns {boolean} <code>true</code> si le champ était différent de
                 *                    <code>"*"</code> ; sinon <code>false</code>.
                 */
                readonly restricted: boolean;
                /**
                 * Retourne la valeur minimale.
                 *
                 * @returns {number} La valeur minimale.
                 */
                readonly min: number;
                /**
                 * Retourne la valeur maximale.
                 *
                 * @returns {number} La valeur maximale.
                 */
                readonly max: number;
                /**
                 * Retourne la liste des valeurs autorisées pour le champ.
                 *
                 * @returns {number[]} La liste des valeurs.
                 */
                values(): number[];
                /**
                 * Applique une fonction sur toutes les valeurs.
                 *
                 * @param {function(number, number, number[]): number} callback La fonction
                 *                                                              appelée sur
                 *                                                              les valeurs.
                 * @returns {Field} Le nouveau champ avec les valeurs modifiées.
                 */
                map(callback: (arg0: number, arg1: number, arg2: number[]) => number): any;
                /**
                 * Teste si une valeur est présente dans la liste des valeurs.
                 *
                 * @param {number} value La valeur qui sera testée.
                 * @returns {boolean} <code>true</code> si la valeur est présente ; sinon
                 *                    <code>false</code>.
                 */
                test(value: number): boolean;
                /**
                 * Calcule la prochaine valeur supérieure à une valeur.
                 *
                 * @param {number} value La valeur initiale.
                 * @returns {number|undefined} La prochaine valeur ; ou
                 *                             <code>undefined</code> si la valeur initiale
                 *                             est supérieure à la valeur maximale.
                 */
                next(value: number): number | undefined;
            };
            /**
             * Les valeurs possibles pour les heures.
             *
             * @type {Field}
             * @private
             */
            _hours: {
                /**
                 * La liste des valeurs autorisées pour le champ (en enlevant les doublons
                 * et en triant).
                 *
                 * @type {number[]}
                 * @private
                 */
                _values: number[];
                /**
                 * <code>true</code> si le champ était différent de <code>"*"</code> ; sinon
                 * <code>false</code>.
                 *
                 * @type {boolean}
                 * @private
                 */
                _restricted: boolean;
                /**
                 * Retourne la marque indiquant si le champ était différent de
                 * <code>"*"</code>.
                 *
                 * @returns {boolean} <code>true</code> si le champ était différent de
                 *                    <code>"*"</code> ; sinon <code>false</code>.
                 */
                readonly restricted: boolean;
                /**
                 * Retourne la valeur minimale.
                 *
                 * @returns {number} La valeur minimale.
                 */
                readonly min: number;
                /**
                 * Retourne la valeur maximale.
                 *
                 * @returns {number} La valeur maximale.
                 */
                readonly max: number;
                /**
                 * Retourne la liste des valeurs autorisées pour le champ.
                 *
                 * @returns {number[]} La liste des valeurs.
                 */
                values(): number[];
                /**
                 * Applique une fonction sur toutes les valeurs.
                 *
                 * @param {function(number, number, number[]): number} callback La fonction
                 *                                                              appelée sur
                 *                                                              les valeurs.
                 * @returns {Field} Le nouveau champ avec les valeurs modifiées.
                 */
                map(callback: (arg0: number, arg1: number, arg2: number[]) => number): any;
                /**
                 * Teste si une valeur est présente dans la liste des valeurs.
                 *
                 * @param {number} value La valeur qui sera testée.
                 * @returns {boolean} <code>true</code> si la valeur est présente ; sinon
                 *                    <code>false</code>.
                 */
                test(value: number): boolean;
                /**
                 * Calcule la prochaine valeur supérieure à une valeur.
                 *
                 * @param {number} value La valeur initiale.
                 * @returns {number|undefined} La prochaine valeur ; ou
                 *                             <code>undefined</code> si la valeur initiale
                 *                             est supérieure à la valeur maximale.
                 */
                next(value: number): number | undefined;
            };
            /**
             * Les valeurs possibles pour le jour du mois.
             *
             * @type {Field}
             * @private
             */
            _date: {
                /**
                 * La liste des valeurs autorisées pour le champ (en enlevant les doublons
                 * et en triant).
                 *
                 * @type {number[]}
                 * @private
                 */
                _values: number[];
                /**
                 * <code>true</code> si le champ était différent de <code>"*"</code> ; sinon
                 * <code>false</code>.
                 *
                 * @type {boolean}
                 * @private
                 */
                _restricted: boolean;
                /**
                 * Retourne la marque indiquant si le champ était différent de
                 * <code>"*"</code>.
                 *
                 * @returns {boolean} <code>true</code> si le champ était différent de
                 *                    <code>"*"</code> ; sinon <code>false</code>.
                 */
                readonly restricted: boolean;
                /**
                 * Retourne la valeur minimale.
                 *
                 * @returns {number} La valeur minimale.
                 */
                readonly min: number;
                /**
                 * Retourne la valeur maximale.
                 *
                 * @returns {number} La valeur maximale.
                 */
                readonly max: number;
                /**
                 * Retourne la liste des valeurs autorisées pour le champ.
                 *
                 * @returns {number[]} La liste des valeurs.
                 */
                values(): number[];
                /**
                 * Applique une fonction sur toutes les valeurs.
                 *
                 * @param {function(number, number, number[]): number} callback La fonction
                 *                                                              appelée sur
                 *                                                              les valeurs.
                 * @returns {Field} Le nouveau champ avec les valeurs modifiées.
                 */
                map(callback: (arg0: number, arg1: number, arg2: number[]) => number): any;
                /**
                 * Teste si une valeur est présente dans la liste des valeurs.
                 *
                 * @param {number} value La valeur qui sera testée.
                 * @returns {boolean} <code>true</code> si la valeur est présente ; sinon
                 *                    <code>false</code>.
                 */
                test(value: number): boolean;
                /**
                 * Calcule la prochaine valeur supérieure à une valeur.
                 *
                 * @param {number} value La valeur initiale.
                 * @returns {number|undefined} La prochaine valeur ; ou
                 *                             <code>undefined</code> si la valeur initiale
                 *                             est supérieure à la valeur maximale.
                 */
                next(value: number): number | undefined;
            };
            /**
             * Les valeurs possibles pour le mois (dont les numéros commencent à zéro
             * pour utiliser la même numérotation que
             * <code>Date.prototype.getMonth()</code>).
             *
             * @type {Field}
             * @private
             */
            _month: {
                /**
                 * La liste des valeurs autorisées pour le champ (en enlevant les doublons
                 * et en triant).
                 *
                 * @type {number[]}
                 * @private
                 */
                _values: number[];
                /**
                 * <code>true</code> si le champ était différent de <code>"*"</code> ; sinon
                 * <code>false</code>.
                 *
                 * @type {boolean}
                 * @private
                 */
                _restricted: boolean;
                /**
                 * Retourne la marque indiquant si le champ était différent de
                 * <code>"*"</code>.
                 *
                 * @returns {boolean} <code>true</code> si le champ était différent de
                 *                    <code>"*"</code> ; sinon <code>false</code>.
                 */
                readonly restricted: boolean;
                /**
                 * Retourne la valeur minimale.
                 *
                 * @returns {number} La valeur minimale.
                 */
                readonly min: number;
                /**
                 * Retourne la valeur maximale.
                 *
                 * @returns {number} La valeur maximale.
                 */
                readonly max: number;
                /**
                 * Retourne la liste des valeurs autorisées pour le champ.
                 *
                 * @returns {number[]} La liste des valeurs.
                 */
                values(): number[];
                /**
                 * Applique une fonction sur toutes les valeurs.
                 *
                 * @param {function(number, number, number[]): number} callback La fonction
                 *                                                              appelée sur
                 *                                                              les valeurs.
                 * @returns {Field} Le nouveau champ avec les valeurs modifiées.
                 */
                map(callback: (arg0: number, arg1: number, arg2: number[]) => number): any;
                /**
                 * Teste si une valeur est présente dans la liste des valeurs.
                 *
                 * @param {number} value La valeur qui sera testée.
                 * @returns {boolean} <code>true</code> si la valeur est présente ; sinon
                 *                    <code>false</code>.
                 */
                test(value: number): boolean;
                /**
                 * Calcule la prochaine valeur supérieure à une valeur.
                 *
                 * @param {number} value La valeur initiale.
                 * @returns {number|undefined} La prochaine valeur ; ou
                 *                             <code>undefined</code> si la valeur initiale
                 *                             est supérieure à la valeur maximale.
                 */
                next(value: number): number | undefined;
            };
            /**
             * Les valeurs possibles pour le jour de la semaine (en utilisant toujours
             * <code>0</code> pour le dimanche pour utiliser la même numéroration que
             * <code>Date.prototype.getDay()</code>).
             *
             * @type {Field}
             * @private
             */
            _day: {
                /**
                 * La liste des valeurs autorisées pour le champ (en enlevant les doublons
                 * et en triant).
                 *
                 * @type {number[]}
                 * @private
                 */
                _values: number[];
                /**
                 * <code>true</code> si le champ était différent de <code>"*"</code> ; sinon
                 * <code>false</code>.
                 *
                 * @type {boolean}
                 * @private
                 */
                _restricted: boolean;
                /**
                 * Retourne la marque indiquant si le champ était différent de
                 * <code>"*"</code>.
                 *
                 * @returns {boolean} <code>true</code> si le champ était différent de
                 *                    <code>"*"</code> ; sinon <code>false</code>.
                 */
                readonly restricted: boolean;
                /**
                 * Retourne la valeur minimale.
                 *
                 * @returns {number} La valeur minimale.
                 */
                readonly min: number;
                /**
                 * Retourne la valeur maximale.
                 *
                 * @returns {number} La valeur maximale.
                 */
                readonly max: number;
                /**
                 * Retourne la liste des valeurs autorisées pour le champ.
                 *
                 * @returns {number[]} La liste des valeurs.
                 */
                values(): number[];
                /**
                 * Applique une fonction sur toutes les valeurs.
                 *
                 * @param {function(number, number, number[]): number} callback La fonction
                 *                                                              appelée sur
                 *                                                              les valeurs.
                 * @returns {Field} Le nouveau champ avec les valeurs modifiées.
                 */
                map(callback: (arg0: number, arg1: number, arg2: number[]) => number): any;
                /**
                 * Teste si une valeur est présente dans la liste des valeurs.
                 *
                 * @param {number} value La valeur qui sera testée.
                 * @returns {boolean} <code>true</code> si la valeur est présente ; sinon
                 *                    <code>false</code>.
                 */
                test(value: number): boolean;
                /**
                 * Calcule la prochaine valeur supérieure à une valeur.
                 *
                 * @param {number} value La valeur initiale.
                 * @returns {number|undefined} La prochaine valeur ; ou
                 *                             <code>undefined</code> si la valeur initiale
                 *                             est supérieure à la valeur maximale.
                 */
                next(value: number): number | undefined;
            };
            /**
             * Teste si une date respecte l'expression.
             *
             * @param {Date} [date=new Date()] La date qui sera testée (ou l'instant
             *                                 présent par défaut).
             * @returns {boolean} <code>true</code> si l'expression est respectée ;
             *                    sinon <code>false</code>.
             */
            test(date?: Date): boolean;
            /**
             * Calcule la prochaine date (ou garde la date de début si les minutes
             * respectent la condition) en vérifiant seulement la condition des minutes.
             *
             * @param {Date} start La date de début.
             * @returns {Date} La prochaine date vérifiant la condition des minutes.
             * @private
             */
            _nextMinutes(start: Date): Date;
            /**
             * Calcule la prochaine date (ou garde la date de début si les heures
             * respectent la condition) en vérifiant seulement la condition des heures.
             *
             * @param {Date} start La date de début.
             * @returns {Date} La prochaine date vérifiant la condition des heures.
             * @private
             */
            _nextHours(start: Date): Date;
            /**
             * Calcule la prochaine date (ou garde la date de début si le jour du mois
             * respecte la condition) en vérifiant seulement la condition du jour du
             * mois.
             *
             * @param {Date} start La date de début.
             * @returns {Date} La prochaine date vérifiant la condition du jour du
             *                 mois.
             * @private
             */
            _nextDate(start: Date): Date;
            /**
             * Calcule la prochaine date (ou garde la date de début si le jour de la
             * semaine respecte la condition) en vérifiant seulement la condition du
             * jour de la semaine.
             *
             * @param {Date} start La date de début.
             * @returns {Date} La prochaine date vérifiant la condition du jour de la
             *                 semaine.
             * @private
             */
            _nextDay(start: Date): Date;
            /**
             * Calcule la prochaine date (ou garde la date de début si le jour du mois
             * ou de la semaine respecte la condition) en vérifiant seulement la
             * condition du jour du mois ou de la semaine.
             *
             * @param {Date} start La date de début.
             * @returns {Date} La prochaine date vérifiant la condition du jour du
             *                 mois ou de la semaine.
             * @private
             */
            _nextDateDay(start: Date): Date;
            /**
             * Calcule la prochaine date (ou garde la date de début si le mois respecte
             * la condition) en vérifiant seulement la condition du mois.
             *
             * @param {Date} start La date de début.
             * @returns {Date} La prochaine date vérifiant la condition du mois.
             * @private
             */
            _nextMonth(start: Date): Date;
            /**
             * Calcule la prochaine date respectant l'expression.
             *
             * @param {Date} [start=new Date()] La date de début (ou l'instant présent
             *                                  par défaut).
             * @returns {Date} La prochaine date respectant l'expression.
             */
            next(start?: Date): Date;
        }[];
        /**
         * La fonction appelée à chaque horaire indiqué dans les expressions
         * <em>cron</em>.
         *
         * @type {Function}
         * @private
         */
        _func: Function;
        /**
         * Le <code>this</code> utilisé pour la fonction.
         *
         * @type {any}
         * @private
         */
        _thisArg: any;
        /**
         * La liste des paramètres passés à la fonction.
         *
         * @type {any[]}
         * @private
         */
        _args: any[];
        /**
         * L'identifiant du minuteur de la prochaine exécution ; ou
         * <code>undefined</code> s'il la tâche est active, mais il n'y a pas de
         * prochaine exécution (car il y a aucune expression <em>cron</em>) ; ou
         * <code>null</code> si la tâche est désactivée.
         *
         * @type {any}
         * @private
         */
        _timeoutID: any;
        /**
         * Récupère l'état de la tâche (active ou non).
         *
         * @returns {boolean} <code>true</code> si la tâche est active ; sinon
         *                    <code>false</code>.
         */
        readonly active: boolean;
        /**
         * Définit le <code>this</code> et les paramètres passés à la fonction.
         *
         * @param {any}    thisArg Le <code>this</code> utilisé pour la fonction.
         * @param {...any} args    Les paramètres passés à la fonction.
         * @returns {Cron} La tâche elle-même.
         */
        bind(thisArg: any, ...args: any[]): any;
        /**
         * Remet les valeurs par défaut pour le <code>this</code> et les paramètres
         * passés à la fonction.
         *
         * @returns {Cron} La tâche elle-même.
         */
        unbind(): any;
        /**
         * Définit les paramètres passés à la fonction.
         *
         * @param {...any} args Les paramètres passés à la fonction.
         * @returns {Cron} La tâche elle-même.
         */
        withArguments(...args: any[]): any;
        /**
         * Exécute manuellement la fonction.
         */
        run(): void;
        /**
         * Programme la prochaine exécution.
         *
         * @private
         */
        _schedule(): void;
        /**
         * Annule les prochaines exécutions.
         *
         * @private
         */
        _cancel(): void;
        /**
         * Active la tâche.
         *
         * @returns {boolean} <code>true</code> quand la tâche a été activée ;
         *                    <code>false</code> si elle était déjà active.
         */
        start(): boolean;
        /**
         * Désactive la tâche.
         *
         * @returns {boolean} <code>true</code> quand la tâche a été désactivée ;
         *                    <code>false</code> si elle était déjà inactive.
         */
        stop(): boolean;
        /**
         * Teste si une date respecte une des expressions <em>cron</em> de la tâche.
         *
         * @param {Date} [date=new Date()] La date qui sera testée (ou l'instant
         *                                 présent par défaut).
         * @returns {boolean} <code>true</code> si une des expressions est
         *                    respectée ; sinon <code>false</code>.
         */
        test(date?: Date): boolean;
        /**
         * Calcule la prochaine date respectant une des expressions <em>cron</em> de
         * la tâche.
         *
         * @param {Date} [start=new Date()] La date de début (ou l'instant présent
         *                                  par défaut).
         * @returns {Date|undefined} La prochaine date respectant une des
         *                           expressions ou <code>undefined</code> s'il n'y
         *                           a pas de prochaine date (quand il y a aucune
         *                           expression <em>cron</em>).
         */
        next(start?: Date): Date | undefined;
    };
};
/**
 * La classe d'une expression <em>cron</em>.
 *
 * @class CronExp
 */
export const CronExp: {
    new (pattern: string): {
        /**
         * Les valeurs possibles pour les minutes.
         *
         * @type {Field}
         * @private
         */
        _minutes: {
            /**
             * La liste des valeurs autorisées pour le champ (en enlevant les doublons
             * et en triant).
             *
             * @type {number[]}
             * @private
             */
            _values: number[];
            /**
             * <code>true</code> si le champ était différent de <code>"*"</code> ; sinon
             * <code>false</code>.
             *
             * @type {boolean}
             * @private
             */
            _restricted: boolean;
            /**
             * Retourne la marque indiquant si le champ était différent de
             * <code>"*"</code>.
             *
             * @returns {boolean} <code>true</code> si le champ était différent de
             *                    <code>"*"</code> ; sinon <code>false</code>.
             */
            readonly restricted: boolean;
            /**
             * Retourne la valeur minimale.
             *
             * @returns {number} La valeur minimale.
             */
            readonly min: number;
            /**
             * Retourne la valeur maximale.
             *
             * @returns {number} La valeur maximale.
             */
            readonly max: number;
            /**
             * Retourne la liste des valeurs autorisées pour le champ.
             *
             * @returns {number[]} La liste des valeurs.
             */
            values(): number[];
            /**
             * Applique une fonction sur toutes les valeurs.
             *
             * @param {function(number, number, number[]): number} callback La fonction
             *                                                              appelée sur
             *                                                              les valeurs.
             * @returns {Field} Le nouveau champ avec les valeurs modifiées.
             */
            map(callback: (arg0: number, arg1: number, arg2: number[]) => number): any;
            /**
             * Teste si une valeur est présente dans la liste des valeurs.
             *
             * @param {number} value La valeur qui sera testée.
             * @returns {boolean} <code>true</code> si la valeur est présente ; sinon
             *                    <code>false</code>.
             */
            test(value: number): boolean;
            /**
             * Calcule la prochaine valeur supérieure à une valeur.
             *
             * @param {number} value La valeur initiale.
             * @returns {number|undefined} La prochaine valeur ; ou
             *                             <code>undefined</code> si la valeur initiale
             *                             est supérieure à la valeur maximale.
             */
            next(value: number): number | undefined;
        };
        /**
         * Les valeurs possibles pour les heures.
         *
         * @type {Field}
         * @private
         */
        _hours: {
            /**
             * La liste des valeurs autorisées pour le champ (en enlevant les doublons
             * et en triant).
             *
             * @type {number[]}
             * @private
             */
            _values: number[];
            /**
             * <code>true</code> si le champ était différent de <code>"*"</code> ; sinon
             * <code>false</code>.
             *
             * @type {boolean}
             * @private
             */
            _restricted: boolean;
            /**
             * Retourne la marque indiquant si le champ était différent de
             * <code>"*"</code>.
             *
             * @returns {boolean} <code>true</code> si le champ était différent de
             *                    <code>"*"</code> ; sinon <code>false</code>.
             */
            readonly restricted: boolean;
            /**
             * Retourne la valeur minimale.
             *
             * @returns {number} La valeur minimale.
             */
            readonly min: number;
            /**
             * Retourne la valeur maximale.
             *
             * @returns {number} La valeur maximale.
             */
            readonly max: number;
            /**
             * Retourne la liste des valeurs autorisées pour le champ.
             *
             * @returns {number[]} La liste des valeurs.
             */
            values(): number[];
            /**
             * Applique une fonction sur toutes les valeurs.
             *
             * @param {function(number, number, number[]): number} callback La fonction
             *                                                              appelée sur
             *                                                              les valeurs.
             * @returns {Field} Le nouveau champ avec les valeurs modifiées.
             */
            map(callback: (arg0: number, arg1: number, arg2: number[]) => number): any;
            /**
             * Teste si une valeur est présente dans la liste des valeurs.
             *
             * @param {number} value La valeur qui sera testée.
             * @returns {boolean} <code>true</code> si la valeur est présente ; sinon
             *                    <code>false</code>.
             */
            test(value: number): boolean;
            /**
             * Calcule la prochaine valeur supérieure à une valeur.
             *
             * @param {number} value La valeur initiale.
             * @returns {number|undefined} La prochaine valeur ; ou
             *                             <code>undefined</code> si la valeur initiale
             *                             est supérieure à la valeur maximale.
             */
            next(value: number): number | undefined;
        };
        /**
         * Les valeurs possibles pour le jour du mois.
         *
         * @type {Field}
         * @private
         */
        _date: {
            /**
             * La liste des valeurs autorisées pour le champ (en enlevant les doublons
             * et en triant).
             *
             * @type {number[]}
             * @private
             */
            _values: number[];
            /**
             * <code>true</code> si le champ était différent de <code>"*"</code> ; sinon
             * <code>false</code>.
             *
             * @type {boolean}
             * @private
             */
            _restricted: boolean;
            /**
             * Retourne la marque indiquant si le champ était différent de
             * <code>"*"</code>.
             *
             * @returns {boolean} <code>true</code> si le champ était différent de
             *                    <code>"*"</code> ; sinon <code>false</code>.
             */
            readonly restricted: boolean;
            /**
             * Retourne la valeur minimale.
             *
             * @returns {number} La valeur minimale.
             */
            readonly min: number;
            /**
             * Retourne la valeur maximale.
             *
             * @returns {number} La valeur maximale.
             */
            readonly max: number;
            /**
             * Retourne la liste des valeurs autorisées pour le champ.
             *
             * @returns {number[]} La liste des valeurs.
             */
            values(): number[];
            /**
             * Applique une fonction sur toutes les valeurs.
             *
             * @param {function(number, number, number[]): number} callback La fonction
             *                                                              appelée sur
             *                                                              les valeurs.
             * @returns {Field} Le nouveau champ avec les valeurs modifiées.
             */
            map(callback: (arg0: number, arg1: number, arg2: number[]) => number): any;
            /**
             * Teste si une valeur est présente dans la liste des valeurs.
             *
             * @param {number} value La valeur qui sera testée.
             * @returns {boolean} <code>true</code> si la valeur est présente ; sinon
             *                    <code>false</code>.
             */
            test(value: number): boolean;
            /**
             * Calcule la prochaine valeur supérieure à une valeur.
             *
             * @param {number} value La valeur initiale.
             * @returns {number|undefined} La prochaine valeur ; ou
             *                             <code>undefined</code> si la valeur initiale
             *                             est supérieure à la valeur maximale.
             */
            next(value: number): number | undefined;
        };
        /**
         * Les valeurs possibles pour le mois (dont les numéros commencent à zéro
         * pour utiliser la même numérotation que
         * <code>Date.prototype.getMonth()</code>).
         *
         * @type {Field}
         * @private
         */
        _month: {
            /**
             * La liste des valeurs autorisées pour le champ (en enlevant les doublons
             * et en triant).
             *
             * @type {number[]}
             * @private
             */
            _values: number[];
            /**
             * <code>true</code> si le champ était différent de <code>"*"</code> ; sinon
             * <code>false</code>.
             *
             * @type {boolean}
             * @private
             */
            _restricted: boolean;
            /**
             * Retourne la marque indiquant si le champ était différent de
             * <code>"*"</code>.
             *
             * @returns {boolean} <code>true</code> si le champ était différent de
             *                    <code>"*"</code> ; sinon <code>false</code>.
             */
            readonly restricted: boolean;
            /**
             * Retourne la valeur minimale.
             *
             * @returns {number} La valeur minimale.
             */
            readonly min: number;
            /**
             * Retourne la valeur maximale.
             *
             * @returns {number} La valeur maximale.
             */
            readonly max: number;
            /**
             * Retourne la liste des valeurs autorisées pour le champ.
             *
             * @returns {number[]} La liste des valeurs.
             */
            values(): number[];
            /**
             * Applique une fonction sur toutes les valeurs.
             *
             * @param {function(number, number, number[]): number} callback La fonction
             *                                                              appelée sur
             *                                                              les valeurs.
             * @returns {Field} Le nouveau champ avec les valeurs modifiées.
             */
            map(callback: (arg0: number, arg1: number, arg2: number[]) => number): any;
            /**
             * Teste si une valeur est présente dans la liste des valeurs.
             *
             * @param {number} value La valeur qui sera testée.
             * @returns {boolean} <code>true</code> si la valeur est présente ; sinon
             *                    <code>false</code>.
             */
            test(value: number): boolean;
            /**
             * Calcule la prochaine valeur supérieure à une valeur.
             *
             * @param {number} value La valeur initiale.
             * @returns {number|undefined} La prochaine valeur ; ou
             *                             <code>undefined</code> si la valeur initiale
             *                             est supérieure à la valeur maximale.
             */
            next(value: number): number | undefined;
        };
        /**
         * Les valeurs possibles pour le jour de la semaine (en utilisant toujours
         * <code>0</code> pour le dimanche pour utiliser la même numéroration que
         * <code>Date.prototype.getDay()</code>).
         *
         * @type {Field}
         * @private
         */
        _day: {
            /**
             * La liste des valeurs autorisées pour le champ (en enlevant les doublons
             * et en triant).
             *
             * @type {number[]}
             * @private
             */
            _values: number[];
            /**
             * <code>true</code> si le champ était différent de <code>"*"</code> ; sinon
             * <code>false</code>.
             *
             * @type {boolean}
             * @private
             */
            _restricted: boolean;
            /**
             * Retourne la marque indiquant si le champ était différent de
             * <code>"*"</code>.
             *
             * @returns {boolean} <code>true</code> si le champ était différent de
             *                    <code>"*"</code> ; sinon <code>false</code>.
             */
            readonly restricted: boolean;
            /**
             * Retourne la valeur minimale.
             *
             * @returns {number} La valeur minimale.
             */
            readonly min: number;
            /**
             * Retourne la valeur maximale.
             *
             * @returns {number} La valeur maximale.
             */
            readonly max: number;
            /**
             * Retourne la liste des valeurs autorisées pour le champ.
             *
             * @returns {number[]} La liste des valeurs.
             */
            values(): number[];
            /**
             * Applique une fonction sur toutes les valeurs.
             *
             * @param {function(number, number, number[]): number} callback La fonction
             *                                                              appelée sur
             *                                                              les valeurs.
             * @returns {Field} Le nouveau champ avec les valeurs modifiées.
             */
            map(callback: (arg0: number, arg1: number, arg2: number[]) => number): any;
            /**
             * Teste si une valeur est présente dans la liste des valeurs.
             *
             * @param {number} value La valeur qui sera testée.
             * @returns {boolean} <code>true</code> si la valeur est présente ; sinon
             *                    <code>false</code>.
             */
            test(value: number): boolean;
            /**
             * Calcule la prochaine valeur supérieure à une valeur.
             *
             * @param {number} value La valeur initiale.
             * @returns {number|undefined} La prochaine valeur ; ou
             *                             <code>undefined</code> si la valeur initiale
             *                             est supérieure à la valeur maximale.
             */
            next(value: number): number | undefined;
        };
        /**
         * Teste si une date respecte l'expression.
         *
         * @param {Date} [date=new Date()] La date qui sera testée (ou l'instant
         *                                 présent par défaut).
         * @returns {boolean} <code>true</code> si l'expression est respectée ;
         *                    sinon <code>false</code>.
         */
        test(date?: Date): boolean;
        /**
         * Calcule la prochaine date (ou garde la date de début si les minutes
         * respectent la condition) en vérifiant seulement la condition des minutes.
         *
         * @param {Date} start La date de début.
         * @returns {Date} La prochaine date vérifiant la condition des minutes.
         * @private
         */
        _nextMinutes(start: Date): Date;
        /**
         * Calcule la prochaine date (ou garde la date de début si les heures
         * respectent la condition) en vérifiant seulement la condition des heures.
         *
         * @param {Date} start La date de début.
         * @returns {Date} La prochaine date vérifiant la condition des heures.
         * @private
         */
        _nextHours(start: Date): Date;
        /**
         * Calcule la prochaine date (ou garde la date de début si le jour du mois
         * respecte la condition) en vérifiant seulement la condition du jour du
         * mois.
         *
         * @param {Date} start La date de début.
         * @returns {Date} La prochaine date vérifiant la condition du jour du
         *                 mois.
         * @private
         */
        _nextDate(start: Date): Date;
        /**
         * Calcule la prochaine date (ou garde la date de début si le jour de la
         * semaine respecte la condition) en vérifiant seulement la condition du
         * jour de la semaine.
         *
         * @param {Date} start La date de début.
         * @returns {Date} La prochaine date vérifiant la condition du jour de la
         *                 semaine.
         * @private
         */
        _nextDay(start: Date): Date;
        /**
         * Calcule la prochaine date (ou garde la date de début si le jour du mois
         * ou de la semaine respecte la condition) en vérifiant seulement la
         * condition du jour du mois ou de la semaine.
         *
         * @param {Date} start La date de début.
         * @returns {Date} La prochaine date vérifiant la condition du jour du
         *                 mois ou de la semaine.
         * @private
         */
        _nextDateDay(start: Date): Date;
        /**
         * Calcule la prochaine date (ou garde la date de début si le mois respecte
         * la condition) en vérifiant seulement la condition du mois.
         *
         * @param {Date} start La date de début.
         * @returns {Date} La prochaine date vérifiant la condition du mois.
         * @private
         */
        _nextMonth(start: Date): Date;
        /**
         * Calcule la prochaine date respectant l'expression.
         *
         * @param {Date} [start=new Date()] La date de début (ou l'instant présent
         *                                  par défaut).
         * @returns {Date} La prochaine date respectant l'expression.
         */
        next(start?: Date): Date;
    };
};
